@@ -31,14 +31,9 @@
 
 #include <krandom.h>
 #include <KLocalizedString>
+#include <QtMath>
 
 
-// this function is used in executer and canvas:
-#define ROUND2INT(x) ( (x) >= 0 ? (int)( (x) + .5 ) : (int)( (x) - .5 ) )
-
-#define DEG2RAD(deg) ( deg * (M_PI / 180) )
-#define RAD2DEG(rad) ( rad * (180 / M_PI) )
-
 void Executer::initialize(TreeNode* tree, ErrorList* _errorList)
 {
 	rootNode       = tree;
@@ -50,7 +45,7 @@ void Executer::initialize(TreeNode* tree, ErrorList* _errorList)
 	breaking       = false;
 	returning      = false;
 	waiting        = false;
-	returnValue    = 0;
+	returnValue    = nullptr;
 	
 	executeCurrent = false;
 
@@ -99,7 +94,7 @@ void Executer::execute()
 		delete calledFunction.variableTable;
 		currentNode = calledFunction.function;
 
-		if (returnValue == 0)
+		if (returnValue == nullptr)
 			currentNode->setNullValue(); // Handle an empty return value
 		else
 			currentNode->setValue(returnValue);
@@ -108,11 +103,11 @@ void Executer::execute()
 		return;
 	}
 
-	if (newScope == 0) {
+	if (newScope == nullptr) {
 		TreeNode* currentParent = currentNode->parent();
 		currentNode = currentNode->nextSibling();
 		
-		if(currentNode == 0) { //running off sibling list
+		if(currentNode == nullptr) { //running off sibling list
 			currentNode = currentParent;
 			
 			if(currentNode == rootNode) {
@@ -134,7 +129,7 @@ void Executer::execute()
 		else
 			currentNode = newScope;
 
-		newScope = 0;
+		newScope = nullptr;
 	}
 
 
@@ -302,7 +297,7 @@ bool Executer::checkParameterType(TreeNode* node, int valueType, int errorCode)
 // 	//qDebug() << "called";
 	uint quantity = node->childCount();
 	TreeNode* currentChild = node->firstChild();
-	while (currentChild != 0) {
+	while (currentChild != nullptr) {
 		if (currentChild->value()->type() != valueType) {
 			switch (valueType) {
 				case Value::String:
@@ -373,7 +368,7 @@ void Executer::executeScope(TreeNode* node) {
 	if(parentTokenType == Token::Learn) {
 		//We have the end of a Learn, so we should return
 		returning = true;
-		returnValue = 0;
+		returnValue = nullptr;
 		return;
 	}
 	newScope = node;
@@ -413,7 +408,7 @@ void Executer::executeFunctionCall(TreeNode* node) {
 	}
 
 	if (returning) {  // if the function is already executed and returns now
-		returnValue = 0;
+		returnValue = nullptr;
 		returning = false;
 		// //qDebug() << "==> functionReturned!";
 		return;
@@ -457,7 +452,7 @@ void Executer::executeExit(TreeNode* node) {
 }
 void Executer::executeIf(TreeNode* node) {
 //	//qDebug() << "called";
-	QString id = QString("__%1_%2").arg(node->token()->look()).arg((quintptr)node);
+	QString id = QString("__%1_%2").arg(node->token()->look()).arg(reinterpret_cast<quintptr>(node));
 	if (currentVariableTable()->contains(id)) {
 		currentVariableTable()->remove(id);
 		return;
@@ -480,7 +475,7 @@ void Executer::executeElse(TreeNode* node) {
 }
 void Executer::executeRepeat(TreeNode* node) {
 //	//qDebug() << "called";
-	QString id = QString("__%1_%2").arg(node->token()->look()).arg((quintptr)node);
+	QString id = QString("__%1_%2").arg(node->token()->look()).arg(reinterpret_cast<quintptr>(node));
 
 	if(breaking) {
 		breaking = false;
@@ -490,7 +485,7 @@ void Executer::executeRepeat(TreeNode* node) {
 
 	// the iteration state is stored on the variable table
 	if (currentVariableTable()->contains(id)) {
-		int currentCount = ROUND2INT((*currentVariableTable())[id].number());
+		int currentCount = static_cast<int>(round((*currentVariableTable())[id].number()));
 		if (currentCount > 0) {
 			(*currentVariableTable())[id].setNumber(currentCount - 1);
 		} else {
@@ -498,10 +493,10 @@ void Executer::executeRepeat(TreeNode* node) {
 			return;
 		}
 	} else {
-		if(ROUND2INT(node->child(0)->value()->number())<=0) // handle 'repeat 0'
+		if(static_cast<int>(round(node->child(0)->value()->number()))<=0) // handle 'repeat 0'
 			return;
 		
-		currentVariableTable()->insert(id, Value((double)(ROUND2INT(node->child(0)->value()->number()) - 1)));
+		currentVariableTable()->insert(id, Value(round(node->child(0)->value()->number()) - 1.0));
 	}
 	newScope = node->child(1);
 }
@@ -512,7 +507,7 @@ void Executer::executeWhile(TreeNode* node) {
 	// so we do the following on every call to executeWhile:
 	//     exec scope, exec expression, exec scope, exec expression, ...
 
-	QString id = QString("__%1_%2").arg(node->token()->look()).arg((quintptr)node);
+	QString id = QString("__%1_%2").arg(node->token()->look()).arg(reinterpret_cast<quintptr>(node));
 
 	if (breaking) {
 		// We hit a break command while executing the scope
@@ -561,7 +556,7 @@ void Executer::executeForTo(TreeNode* node) {
 		firstIteration = true;
 	}
 
-	QString id = QString("__%1_%2").arg(node->token()->look()).arg((quintptr)node);
+	QString id = QString("__%1_%2").arg(node->token()->look()).arg(reinterpret_cast<quintptr>(node));
 
 	if(breaking) {
 		breaking = false;
@@ -615,7 +610,7 @@ void Executer::executeBreak(TreeNode* node) {
 
 	TreeNode* ns = getParentOfTokenTypes(node, &tokenTypes);
 
-	if(ns!=0)
+	if(ns!=nullptr)
 		newScope = ns;
 	//else
 		// We could add an error right HERE
@@ -628,7 +623,7 @@ void Executer::executeReturn(TreeNode* node) {
 	if(node->childCount()>0)
 		returnValue = node->child(0)->value();
 	else
-		returnValue = 0;
+		returnValue = nullptr;
 	returning   = true;
 }
 void Executer::executeWait(TreeNode* node) {
@@ -636,7 +631,7 @@ void Executer::executeWait(TreeNode* node) {
 	if (!checkParameterQuantity(node, 1, 20000+Token::Wait*100+90)) return;
 	if (!checkParameterType(node, Value::Number, 20000+Token::Wait*100+91) ) return;
 	waiting = true;
-	QTimer::singleShot((int)(1000*node->child(0)->value()->number()), this, SLOT(stopWaiting()));
+	QTimer::singleShot(static_cast<int>(1000*node->child(0)->value()->number()), this, SLOT(stopWaiting()));
 }
 void Executer::executeAssert(TreeNode* node) {
 //	//qDebug() << "called";
@@ -969,7 +964,7 @@ void Executer::executeRandom(TreeNode* node) {
 	if (!checkParameterType(node, Value::Number, 20000+Token::Random*100+91)) return;
 	double x = nodeX->value()->number();
 	double y = nodeY->value()->number();
-	double r = (double)(KRandom::random()) / RAND_MAX;
+	double r = static_cast<double>(KRandom::random()) / RAND_MAX;
 	node->value()->setNumber(r * (y - x) + x);
 }
 void Executer::executeGetX(TreeNode* node) {
@@ -1013,42 +1008,42 @@ void Executer::executeTan(TreeNode* node) {
 	if (!checkParameterQuantity(node, 1, 20000+Token::Tan*100+90)) return;
 	
 	double deg = node->child(0)->value()->number();
-	node->value()->setNumber(tan(DEG2RAD(deg)));
+	node->value()->setNumber(tan(qDegreesToRadians(deg)));
 }
 void Executer::executeSin(TreeNode* node) {
 //	//qDebug() << "called";
 	if (!checkParameterQuantity(node, 1, 20000+Token::Sin*100+90)) return;
 	
 	double deg = node->child(0)->value()->number();
-	node->value()->setNumber(sin(DEG2RAD(deg)));
+	node->value()->setNumber(sin(qDegreesToRadians(deg)));
 }
 void Executer::executeCos(TreeNode* node) {
 //	//qDebug() << "called";
 	if (!checkParameterQuantity(node, 1, 20000+Token::Cos*100+90)) return;
 	
 	double deg = node->child(0)->value()->number();
-	node->value()->setNumber(cos(DEG2RAD(deg)));
+	node->value()->setNumber(cos(qDegreesToRadians(deg)));
 }
 void Executer::executeArcTan(TreeNode* node) {
 //	//qDebug() << "called";
 	if (!checkParameterQuantity(node, 1, 20000+Token::ArcTan*100+90)) return;
 	
 	double deg = node->child(0)->value()->number();
-	node->value()->setNumber(RAD2DEG(atan(deg)));
+	node->value()->setNumber(qRadiansToDegrees(atan(deg)));
 }
 void Executer::executeArcSin(TreeNode* node) {
 //	//qDebug() << "called";
 	if (!checkParameterQuantity(node, 1, 20000+Token::ArcSin*100+90)) return;
 	
 	double deg = node->child(0)->value()->number();
-	node->value()->setNumber(RAD2DEG(asin(deg)));
+	node->value()->setNumber(qRadiansToDegrees(asin(deg)));
 }
 void Executer::executeArcCos(TreeNode* node) {
 //	//qDebug() << "called";
 	if (!checkParameterQuantity(node, 1, 20000+Token::ArcCos*100+90)) return;
 	
 	double deg = node->child(0)->value()->number();
-	node->value()->setNumber(RAD2DEG(acos(deg)));
+	node->value()->setNumber(qRadiansToDegrees(acos(deg)));
 }
 void Executer::executeSqrt(TreeNode* node) {
 //	//qDebug() << "called";
@@ -1067,7 +1062,7 @@ void Executer::executeRound(TreeNode* node) {
     if (!checkParameterQuantity(node, 1, 20000+Token::Round*100+90)) return;
    
     double val = node->child(0)->value()->number();
-    node->value()->setNumber((double)ROUND2INT(val));
+    node->value()->setNumber(round(val));
 }
 void Executer::executeGetDirection(TreeNode* node) {
 //	//qDebug() << "called";
@@ -1085,7 +1080,7 @@ void Executer::executeMod(TreeNode* node) {
 	if (!checkParameterType(node, Value::Number, 20000+Token::Mod*100+91)) return;
 	double x = nodeX->value()->number();
 	double y = nodeY->value()->number();
-	double m = (double)(ROUND2INT(x) % ROUND2INT(y));
+	double m = (static_cast<int>(round(x)) % static_cast<int>(round(y)));
 	node->value()->setNumber(m);
 }
 
@@ -1096,7 +1091,7 @@ TreeNode* Executer::getParentOfTokenTypes(TreeNode* child, QList<int>* types) {
 		if(child->parent()->token()->type()==type)
 			return child->parent();
 		else if(child->parent()->token()->type()==Token::Root)
-			return 0;
+			return nullptr;
 	}
 	return getParentOfTokenTypes(child->parent(), types);
 }
